@@ -351,6 +351,19 @@ class Paths(object):
     """
     return os.path.join(self.global_config_dir, '.last_survey_prompt.yaml')
 
+  @property
+  def opt_in_prompting_cache_path(self):
+    """Gets the path to the file to cache information about opt-in prompting.
+
+    This is stored in the config directory instead of the installation state
+    because if the SDK is installed as root, it will fail to persist the cache
+    when you are running gcloud as a normal user.
+
+    Returns:
+      str, The path to the file.
+    """
+    return os.path.join(self.global_config_dir, '.last_opt_in_prompt.yaml')
+
   @property
   def installation_properties_path(self):
     """Gets the path to the installation-wide properties file.
