@@ -310,3 +310,102 @@ class CreateAlpha(CreateBeta):
     parser.display_info.AddCacheUpdater(flags.ManagedZoneCompleter)
     flags.GetPrivateForwardingTargetsArg().AddToParser(parser)
     flags.GetReverseLookupArg().AddToParser(parser)
+    flags.GetServiceDirectoryArg().AddToParser(parser)
+
+  def Run(self, args):
+    # We explicitly want to allow --networks='' as a valid option and we need
+    # to differentiate between that option and not passing --networks at all.
+    if args.visibility == 'public':
+      if args.IsSpecified('networks'):
+        raise exceptions.InvalidArgumentException(
+            '--networks',
+            'If `--visibility` is set to public (default), setting networks is '
+            'not allowed.')
+    if args.visibility == 'private' and args.networks is None:
+      raise exceptions.RequiredArgumentException('--networks', ("""
+           If `--visibility` is set to private, a list of networks must be
+           provided.'
+         NOTE: You can provide an empty value ("") for private zones that
+          have NO network binding.
+          """))
+
+    api_version = util.GetApiFromTrack(self.ReleaseTrack())
+    dns = apis.GetClientInstance('dns', api_version)
+    messages = apis.GetMessagesModule('dns', api_version)
+    registry = util.GetRegistry(api_version)
+
+    zone_ref = registry.Parse(
+        args.dns_zone,
+        params={'project': properties.VALUES.core.project.GetOrFail},
+        collection='dns.managedZones')
+
+    visibility = messages.ManagedZone.VisibilityValueValuesEnum(args.visibility)
+    visibility_config = None
+    if visibility == messages.ManagedZone.VisibilityValueValuesEnum.private:
+      # Handle explicitly empty networks case (--networks='')
+      networks = args.networks if args.networks != [''] else []
+
+      def GetNetworkSelfLink(network):
+        return registry.Parse(
+            network,
+            collection='compute.networks',
+            params={
+                'project': zone_ref.project
+            }).SelfLink()
+
+      network_urls = [GetNetworkSelfLink(n) for n in networks]
+      network_configs = [
+          messages.ManagedZonePrivateVisibilityConfigNetwork(networkUrl=nurl)
+          for nurl in network_urls
+      ]
+      visibility_config = messages.ManagedZonePrivateVisibilityConfig(
+          networks=network_configs)
+
+    if args.forwarding_targets or args.private_forwarding_targets:
+      forwarding_config = command_util.ParseManagedZoneForwardingConfigWithForwardingPath(
+          messages=messages,
+          server_list=args.forwarding_targets,
+          private_server_list=args.private_forwarding_targets)
+    else:
+      forwarding_config = None
+
+    dnssec_config = _MakeDnssecConfig(args, messages)
+    labels = labels_util.ParseCreateArgs(args, messages.ManagedZone.LabelsValue)
+
+    peering_config = None
+    if args.target_project and args.target_network:
+      peering_network = 'https://www.googleapis.com/compute/v1/projects/{}/global/networks/{}'.format(
+          args.target_project, args.target_network)
+      peering_config = messages.ManagedZonePeeringConfig()
+      peering_config.targetNetwork = messages.ManagedZonePeeringConfigTargetNetwork(
+          networkUrl=peering_network)
+
+    reverse_lookup_config = None
+    if args.IsSpecified(
+        'managed_reverse_lookup') and args.managed_reverse_lookup:
+      reverse_lookup_config = messages.ManagedZoneReverseLookupConfig()
+
+    service_directory_config = None
+    if args.service_directory_namespace:
+      service_directory_config = messages.ManagedZoneServiceDirectoryConfig(
+          namespace=messages.ManagedZoneServiceDirectoryConfigNamespace(
+              namespaceUrl=args.service_directory_namespace))
+
+    zone = messages.ManagedZone(
+        name=zone_ref.managedZone,
+        dnsName=util.AppendTrailingDot(args.dns_name),
+        description=args.description,
+        dnssecConfig=dnssec_config,
+        labels=labels,
+        visibility=visibility,
+        forwardingConfig=forwarding_config,
+        privateVisibilityConfig=visibility_config,
+        peeringConfig=peering_config,
+        reverseLookupConfig=reverse_lookup_config,
+        serviceDirectoryConfig=service_directory_config)
+
+    result = dns.managedZones.Create(
+        messages.DnsManagedZonesCreateRequest(
+            managedZone=zone, project=zone_ref.project))
+    log.CreatedResource(zone_ref)
+    return [result]
