@@ -38,9 +38,6 @@ class Update(base.UpdateCommand):
     parser.add_argument(
         '--retention-days', type=int,
         help='A new retention period for the bucket.')
-    parser.add_argument(
-        '--display-name',
-        help='A new display name for the bucket.')
     parser.add_argument(
         '--description',
         help='A new description for the bucket.')
@@ -61,23 +58,21 @@ class Update(base.UpdateCommand):
     if args.IsSpecified('retention_days'):
       bucket_data['retentionDays'] = args.retention_days
       update_mask.append('retention_days')
-    if args.IsSpecified('display_name'):
-      bucket_data['displayName'] = args.display_name
-      update_mask.append('display_name')
     if args.IsSpecified('description'):
       bucket_data['description'] = args.description
       update_mask.append('description')
 
     if not update_mask:
       raise calliope_exceptions.MinimumArgumentException(
-          ['--retention-days', '--display-name', '--description'],
+          ['--retention-days', '--description'],
           'Please specify at least one property to update')
 
     return util.GetClient().projects_locations_buckets.Patch(
         util.GetMessages().LoggingProjectsLocationsBucketsPatchRequest(
             name=util.CreateResourceName(
                 util.CreateResourceName(
-                    util.GetProjectResource().RelativeName(), 'locations',
+                    util.GetProjectResource(args.project).RelativeName(),
+                    'locations',
                     args.location),
                 'buckets', args.BUCKET_ID),
             logBucket=util.GetMessages().LogBucket(**bucket_data),
